const mongoose = require('mongoose');
const Access = require('../models/accessSchema'); 

require('dotenv').config({ path: '../../.env' }); 


// Connect to MongoDB
console.log( 's', process.env.MONGODB_URI);
mongoose.connect(process.env.MONGODB_URI, { useNewUrlParser: true, useUnifiedTopology: true });

const db = mongoose.connection;
db.on('error', console.error.bind(console, 'MongoDB connection error:'));

// Data to seed
const accessData = [
  {
    role: 'SuperAdmin',
    board: {
      activeProjects: true,
      team: true,
      resourcesOnBench: true,
      requestForResources: true,
      requestForResourcesAllocate: true,
      requestForExtensionApproveReject: true,
      myActions: false,
      alerts: false
    },
    timesheet: {
      trackTime: false,
      editTrackedOrEnteredTime: false,
      addTimeEntry: false,
      submitTimesheet: false,
      approveTimesheet: true,
      rejectTimesheet: true,
      viewWeeklyTimesheet: true,
      viewMonthlyTimeEntry: true,
      viewDailyTimesheet: true
    },
    projects: {
      projectsListingActive: true,
      projectsListingClosed: true,
      reopenClosedProjects: true,
      addProjects: true,
      addTeam: true,
      editTeam: true,
      viewTeam: true,
      requestForAdditionalResources: false,
      approveRequestsForResources: true,
      rejectRequestForResources: true,
      requestForExtension: true,
      requestForExtensionApproveReject: true,
      addMilestone: true,
      editMilestone: true,
      viewMilestone: true,
      deleteMilestone: true,
      viewSkillset: true,
      addSkillset: true,
      removeSkillset: true,
      deleteSkillset: true,
      addCRFR: true,
      viewCRFR: true,
      editCRFR: true,
      deleteCRFR: true,
      historyViewAll: true,
      historyViewAllocation: true,
      historyViewExtension: true
    },
    team: {
      viewTeamListing: true,
      addNewTeamMember: true,
      editTeam: true
    },
    report:{
      employeeTimesheetReport : true,
      estimatedVsActualReport : true,
    },
    skillset: {
      viewSkillsetListing: true,
      addNewSkillset: true,
      deleteSkillset: true,
      editSkillset: true
    },
    rolesAndAccess: {
      setAccessForDifferentRoles: true
    }
  },
  {
    role: 'TAM',
    board: {
      activeProjects: false,
      team: false,
      resourcesOnBench: false,
      requestForResources: false,
      requestForResourcesAllocate: false,
      requestForExtensionApproveReject: false,
      myActions: true,
      alerts: true
    },
    timesheet: {
      trackTime: true,
      editTrackedOrEnteredTime: true,
      addTimeEntry: true,
      submitTimesheet: true,
      approveTimesheet: true,
      rejectTimesheet: true,
      viewWeeklyTimesheet: true,
      viewMonthlyTimeEntry: true,
      viewDailyTimesheet: true
    },
    projects: {
      projectsListingActive: true,
      projectsListingClosed: true,
      reopenClosedProjects: false,
      addProjects: false,
      addTeam: false,
      editTeam: false,
      viewTeam: false,
      requestForAdditionalResources: true,
      approveRequestsForResources: false,
      rejectRequestForResources: false,
      requestForExtension: false,
      requestForExtensionApproveReject: false,
      addMilestone: true,
      editMilestone: true,
      viewMilestone: true,
      deleteMilestone: true,
      viewSkillset: true,
      addSkillset: false,
      removeSkillset: false,
      deleteSkillset: false,
      addCRFR: false,
      viewCRFR: true,
      editCRFR: true,
      deleteCRFR: true,
      historyViewAll: true,
      historyViewAllocation: true,
      historyViewExtension: true
    },
    team: {
      viewTeamListing: false,
      addNewTeamMember: false,
      editTeam: false
    },
    skillset: {
      viewSkillsetListing: false,
      addNewSkillset: false,
      deleteSkillset: false,
      editSkillset: false
    },
    rolesAndAccess: {
      setAccessForDifferentRoles: false
    }
  },
  {
    role: 'ResourceManager',
    board: {
      activeProjects: true,
      team: true,
      resourcesOnBench: true,
      requestForResources: true,
      requestForResourcesAllocate: true,
      requestForExtensionApproveReject: true,
      myActions: false,
      alerts: false
    },
    timesheet: {
      trackTime: false,
      editTrackedOrEnteredTime: false,
      addTimeEntry: false,
      submitTimesheet: false,
      approveTimesheet: false,
      rejectTimesheet: false,
      viewWeeklyTimesheet: false,
      viewMonthlyTimeEntry: true,
      viewDailyTimesheet: true
    },
    projects: {
      projectsListingActive: true,
      projectsListingClosed: true,
      reopenClosedProjects: false,
      addProjects: false,
      addTeam: true,
      editTeam: true,
      viewTeam: true,
      requestForAdditionalResources: false,
      approveRequestsForResources: true,
      rejectRequestForResources: true,
      requestForExtension: true,
      requestForExtensionApproveReject: true,
      addMilestone: false,
      editMilestone: false,
      viewMilestone: true,
      deleteMilestone: false,
      viewSkillset: true,
      addSkillset: false,
      removeSkillset: false,
      deleteSkillset: false,
      addCRFR: false,
      viewCRFR: true,
      editCRFR: false,
      deleteCRFR: false,
      historyViewAll: true,
      historyViewAllocation: true,
      historyViewExtension: true
    },
    team: {
      viewTeamListing: true,
      addNewTeamMember: true,
      editTeam: true
    },
    skillset: {
      viewSkillsetListing: false,
      addNewSkillset: false,
      deleteSkillset: false,
      editSkillset: false
    },
    rolesAndAccess: {
      setAccessForDifferentRoles: false
    }
  },
  {
    role: 'Employee',
    board: {
      activeProjects: false,
      team: false,
      resourcesOnBench: false,
      requestForResources: false,
      requestForResourcesAllocate: false,
      requestForExtensionApproveReject: false,
      myActions: true,
      alerts: true
    },
    timesheet: {
      trackTime: true,
      editTrackedOrEnteredTime: true,
      addTimeEntry: true,
      submitTimesheet: true,
      approveTimesheet: false,
      rejectTimesheet: false,
      viewWeeklyTimesheet: true,
      viewMonthlyTimeEntry: true,
      viewDailyTimesheet: true
    },
    projects: {
      projectsListingActive: false,
      projectsListingClosed: false,
      reopenClosedProjects: false,
      addProjects: false,
      addTeam: false,
      editTeam: false,
      viewTeam: false,
      requestForAdditionalResources: false,
      approveRequestsForResources: false,
      rejectRequestForResources: false,
      requestForExtension: false,
      requestForExtensionApproveReject: false,
      addMilestone: false,
      editMilestone: false,
      viewMilestone: false,
      deleteMilestone: false,
      viewSkillset: false,
      addSkillset: false,
      removeSkillset: false,
      deleteSkillset: false,
      addCRFR: false,
      viewCRFR: false,
      editCRFR: false,
      deleteCRFR: false,
      historyViewAll: false,
      historyViewAllocation: false,
      historyViewExtension: false
    },
    team: {
      viewTeamListing: false,
      addNewTeamMember: false,
      editTeam: false
    },
    skillset: {
      viewSkillsetListing: false,
      addNewSkillset: false,
      deleteSkillset: false,
      editSkillset: false
    },
    rolesAndAccess: {
      setAccessForDifferentRoles: false
    }
  },
  {
    role: 'HR',
    board: {
      activeProjects: false,
      team: false,
      resourcesOnBench: false,
      requestForResources: false,
      requestForResourcesAllocate: false,
      requestForExtensionApproveReject: false,
      myActions: true,
      alerts: true
    },
    timesheet: {
      trackTime: true,
      editTrackedOrEnteredTime: true,
      addTimeEntry: true,
      submitTimesheet: true,
      approveTimesheet: true,
      rejectTimesheet: true,
      viewWeeklyTimesheet: true,
      viewMonthlyTimeEntry: true,
      viewDailyTimesheet: true
    },
    projects: {
      projectsListingActive: true,
      projectsListingClosed: true,
      reopenClosedProjects: false,
      addProjects: false,
      addTeam: false,
      editTeam: false,
      viewTeam: false,
      requestForAdditionalResources: true,
      approveRequestsForResources: false,
      rejectRequestForResources: false,
      requestForExtension: false,
      requestForExtensionApproveReject: false,
      addMilestone: true,
      editMilestone: true,
      viewMilestone: true,
      deleteMilestone: true,
      viewSkillset: true,
      addSkillset: false,
      removeSkillset: false,
      deleteSkillset: false,
      addCRFR: false,
      viewCRFR: true,
      editCRFR: true,
      deleteCRFR: true,
      historyViewAll: true,
      historyViewAllocation: true,
      historyViewExtension: true
    },
    team: {
      viewTeamListing: false,
      addNewTeamMember: false,
      editTeam: false
    },
    skillset: {
      viewSkillsetListing: false,
      addNewSkillset: false,
      deleteSkillset: false,
      editSkillset: false
    },
    rolesAndAccess: {
      setAccessForDifferentRoles: false
    }
  },
  {
    role: 'Sales',
    board: {
      activeProjects: false,
      team: false,
      resourcesOnBench: false,
      requestForResources: false,
      requestForResourcesAllocate: false,
      requestForExtensionApproveReject: false,
      myActions: true,
      alerts: true
    },
    timesheet: {
      trackTime: true,
      editTrackedOrEnteredTime: true,
      addTimeEntry: true,
      submitTimesheet: true,
      approveTimesheet: true,
      rejectTimesheet: true,
      viewWeeklyTimesheet: true,
      viewMonthlyTimeEntry: true,
      viewDailyTimesheet: true
    },
    projects: {
      projectsListingActive: true,
      projectsListingClosed: true,
      reopenClosedProjects: false,
      addProjects: false,
      addTeam: false,
      editTeam: false,
      viewTeam: false,
      requestForAdditionalResources: true,
      approveRequestsForResources: false,
      rejectRequestForResources: false,
      requestForExtension: false,
      requestForExtensionApproveReject: false,
      addMilestone: true,
      editMilestone: true,
      viewMilestone: true,
      deleteMilestone: true,
      viewSkillset: true,
      addSkillset: false,
      removeSkillset: false,
      deleteSkillset: false,
      addCRFR: false,
      viewCRFR: true,
      editCRFR: true,
      deleteCRFR: true,
      historyViewAll: true,
      historyViewAllocation: true,
      historyViewExtension: true
    },
    team: {
      viewTeamListing: false,
      addNewTeamMember: false,
      editTeam: false
    },
    skillset: {
      viewSkillsetListing: false,
      addNewSkillset: false,
      deleteSkillset: false,
      editSkillset: false
    },
    rolesAndAccess: {
      setAccessForDifferentRoles: false
    }
  },
];

// Function to seed Access data
const seedAccess = async () => {
  try {
    // Remove existing data (optional)
    await Access.deleteMany({});

    // Create and save new Access documents
    await Access.insertMany(accessData);

    console.log('Access data seeded successfully');
    db.close();
  } catch (error) {
    console.error('Error seeding Access data:', error);
    db.close();
  }
};

// Call the seedAccess function to start seeding
seedAccess();