// profile.controller.js
const profileService = require('./Services/profile.service');
const fs = require('fs');
const path = require('path');

const getProfile = async (req, res) => {
  try {
    const profile = await profileService.getProfile(req.query.id);
    res.json(profile);
  } catch (error) {
    res.status(500).json({ message: 'Server error', error: error.message });
  }
};

const updateProfile = async (req, res) => {
  try {
    const updatedProfile = await profileService.updateProfile(req.query.id, req.body);
    res.json(updatedProfile);
  } catch (error) {
    res.status(500).json({ message: 'Server error', error: error.message });
  }
};

const resetPassword = async (req, res) => {
  try {
    // Ensure all required fields are present
    const { email, currentPassword, newPassword, confirmNewPassword } = req.body;
    if (!email || !currentPassword || !newPassword || !confirmNewPassword) {
      return res.status(400).json({ message: 'All fields are required.' });
    }
    // Check if new password and confirm new password match
    if (newPassword !== confirmNewPassword) {
      return res.status(400).json({ message: 'New password and confirm new password do not match.' });
    }
    const result = await profileService.resetPassword(email, currentPassword, newPassword);
    res.json(result);
  } catch (error) {
    res.status(500).json({ message: 'Server error', error: error.message });
  }
};

const resetPasswordNew = async (req, res) => {
  try {
    // Ensure all required fields are present
    const { email, newPassword, confirmNewPassword } = req.body;
    if (!email || !newPassword || !confirmNewPassword) {
      return res.status(400).json({ message: 'All fields are required.' });
    }
    // Check if new password and confirm new password match
    if (newPassword !== confirmNewPassword) {
      return res.status(400).json({ message: 'New password and confirm new password do not match.' });
    }
    const result = await profileService.resetPasswordNew(email, newPassword);
    res.json(result);
  } catch (error) {
    res.status(500).json({ message: 'Server error', error: error.message });
  }
};


const getProfilePicture = async (req, res) => {
  try {
    const profile = await profileService.getProfile(req.query.id);
    if (!profile || !profile.profilePicture) {
      return res.status(404).send('Profile picture not found');
    }
    const picturePath = path.join(__dirname, '../', profile.profilePicture);
    if (!fs.existsSync(picturePath)) {
      return res.status(404).send('Profile picture not found');
    }
    res.sendFile(picturePath);
  } catch (error) {
    res.status(500).json({ message: 'Server error', error: error.message });
  }
};

const uploadProfilePicture = async (req, res) => {
  try {
    if (!req.file) {
      return res.status(400).send('No file uploaded');
    }
    const updatedProfile = await profileService.updateProfilePicture(req.query.id, req.file.path);
    res.json(updatedProfile);
  } catch (error) {
    res.status(500).json({ message: 'Server error', error: error.message });
  }
};

const deleteProfilePicture = async (req, res) => {
  try {
    const updatedProfile = await profileService.deleteProfilePicture(req.query.id);
    res.json(updatedProfile);
  } catch (error) {
    res.status(500).json({ message: 'Server error', error: error.message });
  }
};

module.exports = {
  getProfile,
  updateProfile,
  resetPassword,  
  getProfilePicture,
  uploadProfilePicture,
  deleteProfilePicture,
  resetPasswordNew
};
