const Employee = require('../../database/models/employeeSchema');

const findById = async (id) => {
  return await Employee.findById(id).select('-password -refreshToken -__v');
};

const updateById = async (id, profileData) => {
  return await Employee.findByIdAndUpdate(id, profileData, { new: true, runValidators: true }).select('-password -refreshToken -__v');
};

const updateProfilePicture = async (id, picturePath) => {
  return await Employee.findByIdAndUpdate(id, { profilePicture: picturePath }, { new: true }).select('-password -refreshToken -__v');
};

const deleteProfilePicture = async (id) => {
  return await Employee.findByIdAndUpdate(id, { $unset: { profilePicture: 1 } }, { new: true }).select('-password -refreshToken -__v');
};

const findByEmail = async (email) => {
  return await Employee.findOne({ email }).select('+password');  // Include password for comparison
};

const resetPasswordByEmail = async (email, hashedPassword) => {
  return await Employee.findOneAndUpdate({ email }, { password: hashedPassword }, { new: true }).select('-password -refreshToken -__v');
};

// New repository function for resetting password without current password
const resetPasswordByEmailWithoutCurrent = async (email, hashedPassword) => {
  return await Employee.findOneAndUpdate(
    { email },
    { password: hashedPassword },
    { new: true }
  ).select('-password -refreshToken -__v');
};





module.exports = {
  findById,
  updateById,
  updateProfilePicture,
  deleteProfilePicture,
  findByEmail,
  resetPasswordByEmail,
  resetPasswordByEmailWithoutCurrent
};
