const mongoose = require('mongoose');
const TimeEntry = require('../../database/models/timeEntrySchema');


const getTimeLogs = async (query) => {
  return await TimeEntry.find(query)
    .populate('projectId', 'name')
    .populate('employeeId', 'name employeeId dateOfJoining');
};

const getProjectTasks = async (projectId) => {
  try {
    const result = await TimeEntry.aggregate([
      {
        $match: {
          projectId: new mongoose.Types.ObjectId(projectId),
          approved: true
        }
      },
      {
        $group: {
          _id: '$taskId',
          totalDuration: { $sum: '$duration' },
          taskDescriptions: { $addToSet: '$description' }
        }
      },
      {
        $project: {
          taskId: '$_id',
          totalDuration: 1,
          taskDescriptions: 1
        }
      },
      {
        $sort: { taskId: 1 }
      }
    ]);

    return result;
  } catch (error) {
    console.error('Error in TaskRepository.getProjectTasks:', error);
    throw error;
  }
};




module.exports = {

  getTimeLogs,
  getProjectTasks


};