/* eslint-disable no-useless-catch */
const roleRepository = require('../role.repository');
const accessRepository = require('../role.repository');
const employeeRepository = require('../role.repository');


const addRole = async (roleData) => {
  try {
    return await roleRepository.createRole(roleData);
  } catch (error) {
    throw new Error('Error creating role: ' + error.message);
  }
};

const getAllRoles = async () => {
  try {
    return await roleRepository.findAllRoles();
  } catch (error) {
    throw error;
  }
};

const createAccess = async (data) => {
  try {
    return await accessRepository.createAccess(data);
  } catch (error) {
    throw error;
  }
};

const getEmployeeDetails = async (employeeId) => {
  try {
    // Use populate after obtaining the query object
    const employee = await employeeRepository.findEmployeeById(employeeId)
      .populate({
        path: 'role',
        populate: {
          path: 'access'
        }
      });

    return employee;
  } catch (error) {
    throw error;
  }
};


const updateRoleAccess = async (roleId, updateData) => { 
  try {
    const role = await roleRepository.findRoleById(roleId);
    if (!role) {
      throw new Error('Role not found');
    }

    const access = await accessRepository.findAccessById(role.access);
    if (!access) {
      throw new Error('Access not found');
    }

    // Update the access permissions
    for (let key in updateData) {
      if (access[key] !== undefined) {
        access[key] = updateData[key];
      }
    }

    // Update the routes (assuming updateData.routes is an array)
    if (Array.isArray(updateData.routes)) {
      role.routes = updateData.routes;
    }

    await access.save();
    await role.save();

    return role;
  } catch (error) {
    console.error('Error updating access:', error);
    throw new Error('Error updating access: ' + error.message);
  }
};

const getRoleDetails = async (roleId) => {
  try {
    const roleDetails = await roleRepository.findRoleById(roleId);
    return roleDetails;
  } catch (error) {
    throw new Error('Error fetching role details: ' + error.message);
  }
};

module.exports = {
  addRole,
  createAccess,
  getAllRoles,
  getEmployeeDetails,
  updateRoleAccess ,
  getRoleDetails
};
