const roleService = require('./Services/role.service');
const accessService = require('./Services/role.service');
const employeeService = require('./Services/role.service');

const createRole = async (req, res) => {
  try {
    const role = await roleService.addRole(req.body);
    res.status(201).json(role);
  } catch (error) {
    res.status(500).json({ error: error.message });
  }
};

const getAllRoles = async (req, res) => {
  try {
    const roles = await roleService.getAllRoles();
    res.status(200).json(roles);
  } catch (error) {
    res.status(500).json({ message: error.message });
  }
};

// For post some access with key value (testing purpose only)
const createAccess = async (req, res) => {
  try {
    const data = req.body;
    const newAccess = await accessService.createAccess(data);
    res.status(201).json(newAccess);
  } catch (error) {
    res.status(500).json({ message: error.message });
  }
};

const getEmployeeDetails = async (req, res) => {
  try {
    const employeeId = req.params.id; // Get the employee ID from the request params
    const employee = await employeeService.getEmployeeDetails(employeeId);

    if (!employee) {
      return res.status(404).json({ message: 'Employee not found' });
    }

    res.status(200).json(employee);
  } catch (error) {
    res.status(500).json({ message: error.message });
  }
};

const updateRoleAccess = async (req, res) => { // Updated function
  try {
    const roleId = req.params.id;
    const updateData = req.body;
    const updatedRole = await roleService.updateRoleAccess(roleId, updateData);

    if (!updatedRole) {
      return res.status(404).json({ message: 'Role not found' });
    }

    res.status(200).json(updatedRole);
  } catch (error) {
    res.status(500).json({ message: error.message });
  }
};

const getRoleDetails = async (req, res) => {
  try {
    const roleId = req.params.id;
    const roleDetails = await roleService.getRoleDetails(roleId);

    if (!roleDetails) {
      return res.status(404).json({ message: 'Role not found' });
    }

    res.status(200).json(roleDetails);
  } catch (error) {
    res.status(500).json({ message: error.message });
  }
};

module.exports = {
  createRole,
  createAccess,
  getAllRoles,
  getEmployeeDetails,
  updateRoleAccess,
  getRoleDetails 
};
