const projectService = require('./Services/project.service');
const Employee = require('../../../database/models/employeeSchema');
const Role = require('../../../database/models/roleSchema');
const getAllProjectByStatus = async (req, res) => {
  try {
    const { tab } = req.params;
    const { search, page = 1, limit = 5 } = req.query;
    const projects = await projectService.getAllProjectByStatus(search, tab, page, limit);
    res.json(projects);
  } catch (error) {
    res.status(500).json({ message: 'Server error', error: error.message });
  }
};

const getAllProject = async (req, res) => {
  try {
    const { search,status } = req.query;
    const page = parseInt(req.query.page, 10) || 1;
    const limit = parseInt(req.query.limit, 10) || 5;
    const projects = await projectService.getAllProject(search, page, limit, status);
    res.json(projects);
  } catch (error) {
    res.status(500).json({ message: 'Server error', error: error.message });
  }
};


async function getRoleIdByName(role) {
  try {
    const roleid = await Role.findOne({ roleName: role });
    if (!role) {
      throw new Error(`Role with name "${role}" not found`);
    }
    return roleid._id;
  } catch (error) {
    console.error(`Error fetching role ID for ${role}:`, error);
    throw error;
  }
}

const getProjectById = async (req, res) => {
  try {
    const project = await projectService.getProjectById(req.params.id);
    if (!project) {
      return res.status(404).json({
        message: 'Project not found'
      });
    }

    res.json(project);
  } catch (error) {
    res.status(500).json({ message: 'Server error', error: error.message });
  }
};

const editProjectById = async (req, res) => {
  try {
    const updatedProject = await projectService.editProjectById(req.params.id, req.body);
    if (!updatedProject) {
      return res.status(404).json({ message: 'Project not found' });
    }
    res.json(updatedProject);
  } catch (error) {
    res.status(500).json({ message: 'Server error', error: error.message });
  }
};

const addProject = async (req, res) => {
  try {
    const newProject = await projectService.addProject(req.body);
    const { tam } = req.body; // Assuming tam ID is sent in the request body
    await Employee.findByIdAndUpdate(tam, {
      $push: { TAMofProjects: newProject._id }
    });
    const employee = await Employee.findById(tam);
    employee.role = employee.TAMofProjects.length ? await getRoleIdByName('TAM') : await getRoleIdByName('Employee'); // Assign role based on TAMofProjects length
    await employee.save();
    res.status(201).json(newProject);
  } catch (error) {
    if (error.message === 'A project with this name already exists') {
      res.status(409).json({ message: error.message });
    } else {
      console.error(error);
      res.status(500).json({ message: 'Server error', error: error.message });
    }
  }
};

const deleteProjectById = async (req, res) => {
  try {
    const deletedProject = await projectService.deleteProjectById(req.params.id);
    res.json({ message: 'Project soft deleted', deletedProject });
  } catch (error) {
    if (error.message === 'Project not found') {
      res.status(404).json({ message: error.message });
    } else {
      console.error(error);
      res.status(500).json({ message: 'Server error', error: error.message });
    }
  }
};


module.exports = {
  getAllProjectByStatus,
  getProjectById,
  editProjectById,
  addProject,
  deleteProjectById,
  getAllProject

};
