const teamMemberService = require('./Services/projectTeamMember.service');

const getProjectTeamMembers = async (req, res) => {
  try {
    const teamMembers = await teamMemberService.getProjectTeamMembers();
    res.json(teamMembers);
  } catch (error) {
    console.error(error);
    res.status(500).send('Server error');
  }
};

const getProjectTeamMemberById = async (req, res) => {
  try {
    const id = req.params.id;
    if (!id) {
      return res.status(400).send('ID is required');
    }

    const teamMember = await teamMemberService.getProjectTeamMemberById(id);
    if (!teamMember) {
      return res.status(404).send('Team member not found');
    }

    res.json(teamMember);
  } catch (error) {
    res.status(500).send('Server error');
  }
};

const getProjectTeamMembersByProjectId = async (req, res) => {
  try {
    const projectId = req.params.projectId;
    const { search, page = 1, limit = 10 } = req.query;
    
    if (!projectId) {
      return res.status(400).send('Project ID is required');
    }

    const teamMembers = await teamMemberService.getProjectTeamMembersByProjectId(projectId, search, page, limit);
    res.json(teamMembers);
  } catch (error) {
    console.error(error);
    res.status(500).send('Server error');
  }
};

const addProjectTeamMember = async (req, res) => {
  try {
    const newTeamMember = await teamMemberService.addProjectTeamMember(req.body);
    res.json(newTeamMember);
  } catch (error) {
    console.error(error);
    if (error.code === 11000) {
      res.status(400).send({ message: 'Duplicate key error', details: error.keyValue });
    } else {
      res.status(500).send({ message: 'Internal server error', details: error.message });
    }
  }
};

const editProjectTeamMember = async (req, res) => {
  try {
    const id = req.params.id;
    if (!id) {
      return res.status(400).send('ID is required');
    }

    const updatedTeamMember = await teamMemberService.editProjectTeamMember(id, req.body);
    res.json(updatedTeamMember);
  } catch (error) {
    res.status(500).send('Server error');
  }
};

const deleteProjectTeamMember = async (req, res) => {
  try {
    const id = req.params.id;
    if (!id) {
      return res.status(400).send('ID is required');
    }
    const deletedMember = await teamMemberService.deleteProjectTeamMember(id);
    res.json({ message: 'Team member soft deleted', deletedMember });
  } catch (error) {
    if (error.message === 'Team member not found') {
      res.status(404).send(error.message);
    } else {
      console.error(error);
      res.status(500).send('Server error');
    }
  }
};

module.exports = {
  getProjectTeamMembers,
  getProjectTeamMemberById,
  getProjectTeamMembersByProjectId,
  addProjectTeamMember,
  editProjectTeamMember,
  deleteProjectTeamMember
};
