const ProjectTeamMember = require('../../../database/models/project/projectTeamMemberSchema');
const applySearchAndPagination = require('../../../utils/paginationAndSearch');

const findAll = async () => {
  return await ProjectTeamMember.find({ visibility: true }).populate([
    {
      path: 'employee',
      select: 'name type employeeId designation skillset',
      populate: {
        path: 'skillset',
        select: 'name'
      }
    },
    {
      path: 'project',
      select: 'name type startDate endDate estimatedHours workedHours tam description closuredate'
    }
  ]);
};


const findById = async (id) => {
  return await ProjectTeamMember.findById({ _id: id, visibility: true }).populate({
    path: 'employee',
    select: 'name type employeeId designation skillset',
    populate: {
      path: 'skillset',
      select: 'name'
    }
  });
};

const findByProjectId = async (projectId, search, page, limit) => {
  // Adjusted search fields to correctly reference nested employee fields
  const searchFields = ['role', 'employee.name', 'employee.employeeId', 'employee.designation'];
  const populateFields = [
    {
      path: 'employee',
      select: 'name type employeeId designation skillset',
      populate: {
        path: 'skillset',
        select: 'name'
      }
    }
  ];
  const baseQuery = { project: projectId, visibility: true };
  return await applySearchAndPagination(ProjectTeamMember, searchFields, search, page, limit, populateFields, false, baseQuery);
};


const create = async (teamMemberData) => {
  const newTeamMember = new ProjectTeamMember(teamMemberData);
  return await newTeamMember.save();
};

const updateById = async (id, teamMemberData) => {
  return await ProjectTeamMember.findOneAndUpdate({ _id: id, visibility: true }, teamMemberData, { new: true }).populate({
    path: 'employee',
    select: 'name type employeeId designation skillset',
    populate: {
      path: 'skillset',
      select: 'name'
    }
  });
};

const deleteById = async (id) => {
  return await ProjectTeamMember.findByIdAndUpdate(id, { visibility: false }, { new: true });
};

module.exports = {
  findAll,
  findById,
  findByProjectId,
  create,
  updateById,
  deleteById
};
