const crfrRepository = require('../Projectcrfr.repository');
const mongoose = require('mongoose');

const getCRFRs = async (search, page, limit, projectId) => {
  if (projectId && mongoose.Types.ObjectId.isValid(projectId)) {
    return await crfrRepository.findByProjectId(mongoose.Types.ObjectId(projectId), search, page, limit);
  }
  return await crfrRepository.findAllWithSearchAndPagination(search, page, limit);
};


const getCRFRByProjectId = async (projectId, search, page, limit) => {
  return await crfrRepository.findByProjectId(projectId, search, page, limit);
};


// const createCRFR = async (crfrData) => {
//   return await crfrRepository.create(crfrData);
// };

const Joi = require('joi');

const crfrSchema = Joi.object({
  crfrId: Joi.string().required(),
  approvedOn: Joi.date().required(),
  startDate: Joi.date().required(),
  status: Joi.string().required(),
  closureDate: Joi.date().optional(),
  visibility: Joi.boolean().default(true),
  projectID: Joi.string().required(),
  sowFile: Joi.string().optional()
});

const createCRFR = async (crfrData) => {
  const { error } = crfrSchema.validate(crfrData);
  if (error) {
    throw new Error(`Validation error: ${error.details[0].message}`);
  }
  return await crfrRepository.create(crfrData);
};



const updateCRFR = async (id, crfrData) => {
  return await crfrRepository.updateById(id, crfrData);
};

const deleteCRFR = async (id) => {
  return await crfrRepository.deleteById(id);
};

const getCRFRById = async (id) => {
  return await crfrRepository.findById(id);
};

module.exports = {
  getCRFRs,
  getCRFRByProjectId,
  createCRFR,
  updateCRFR,
  deleteCRFR,
  getCRFRById
};
