const milestoneRepository = require('../milestone.repository');
const { validateMilestone } = require('../../../../database/models/project/milestoneSchema');

const getMilestones = async (search, page, limit) => {
  return await milestoneRepository.findAllWithSearchAndPagination(search, page, limit);
};

const getMilestoneById = async (id) => {
  return await milestoneRepository.findById(id);
};

const getMilestonesByProjectId = async (projectId, search, page, limit) => {
  return await milestoneRepository.findByProjectId(projectId, search, page, limit);
};

const addMilestone = async (milestoneData) => {
 
  const { error } = validateMilestone(milestoneData);
  if (error) {
    console.error('Validation error:', error.details);
    throw new Error(error.details[0].message);
  }
  
  const formattedData = {
    ...milestoneData,
    startDate: new Date(milestoneData.startDate),
    endDate: new Date(milestoneData.endDate),
    releaseDate: new Date(milestoneData.releaseDate),
  };
  
  return await milestoneRepository.create(formattedData);
};

const editMilestone = async (id, milestoneData) => {
  const { error } = validateMilestone(milestoneData);
  if (error) throw new Error(error.details[0].message);
  
  const formattedData = {
    ...milestoneData,
    startDate: new Date(milestoneData.startDate),
    endDate: new Date(milestoneData.endDate),
    releaseDate: new Date(milestoneData.releaseDate),
  };

  return await milestoneRepository.updateById(id, formattedData);
};

const deleteMilestone = async (id) => {
  return await milestoneRepository.deleteById(id);
};

module.exports = {
  getMilestones,
  getMilestoneById,
  addMilestone,
  editMilestone,
  deleteMilestone,
  getMilestonesByProjectId 
};