const ProjectSkillsetRepository = require('../Projectskillset.repository');
const Skillset = require('../../../../database/models/skillset');

const addSkillsetsToProject = async (projectId, skillsetIds) => {
  try {
    // Validate the skillset IDs
    const validSkillsets = await Skillset.find({ '_id': { $in: skillsetIds } });
    if (validSkillsets.length !== skillsetIds.length) {
      return { status: 400, data: { message: 'Invalid skillset IDs' } };
    }

    const project = await ProjectSkillsetRepository.addSkillsetsToProject(projectId, skillsetIds);
    if (!project) {
      return { status: 404, data: { message: 'Project not found' } };
    }

    return { status: 200, data: { message: 'Skillsets added to project', project } };
  } catch (error) {
    return { status: 500, data: { message: 'Internal server error', error } };
  }
};


const getProjectWithSkillsets = async (projectId, search, page, limit) => {
  try {
    const { project, totalSkillsets } = await ProjectSkillsetRepository.getProjectWithSkillsets(projectId, search, page, limit);

    if (!project) {
      return { status: 404, message: 'Project not found' };
    }

    return {
      status: 200,
      data: {
        // project,
        skillsets: project.skillsets,
        totalSkillsets,
        page,
        limit
      }
    };
  } catch (error) {
    return { status: 500, message: 'Internal server error', error };
  }
};

const deleteSkillsetFromProject = async (projectId, skillsetId) => {
  try {
    // Call repository function to delete skillset from project
    const result = await ProjectSkillsetRepository.deleteSkillsetFromProject(projectId, skillsetId);
    return { status: 200, data: result };
  } catch (error) {
    console.error('Error in service deleting skillset from project:', error);
    throw error;
  }
};

const getProjectSkillset = async (search, page, limit) => {
  return await ProjectSkillsetRepository.findAllWithSearchAndPagination(search, page, limit);
};

module.exports = {
  deleteSkillsetFromProject,
  getProjectWithSkillsets,
  addSkillsetsToProject,
  getProjectSkillset
};