const Allocation = require('../../../database/models/project/requsestResourceSchema');
const applySearchAndPagination = require('../../../utils/paginationAndSearch');


exports.findAllPendingRequests = async (search, page, limit, fetchAll = false) => {
  // Define any specific search fields and base query if needed
  const searchFields = ['projectId.name', 'skillSet.name']; // Adjust search fields based on your schema
  const baseQuery = { status: 'Pending' }; // Base query to filter pending requests
  
  // Define fields to populate
  const populateFields = [
    { path: 'skillSet', select: 'name' },
    { path: 'projectId', select: 'name' } // Assuming you want to populate project details as well
  ];

  // Use applySearchAndPagination to get results with search and pagination
  return await applySearchAndPagination(
    Allocation,
    searchFields,
    search,
    page,
    limit,
    populateFields,
    fetchAll, // Pass fetchAll flag from function parameter
    baseQuery
  );
};


exports.saveAllocation = async (allocationData) => {
  const newAllocation = new Allocation(allocationData);
  newAllocation.history.push({
    requestedEmployeeNames: [],
    updatedEmployeeRole: allocationData.requestedBy,
    status: 'pending',
    date: new Date()
  });
  return await newAllocation.save();
};

exports.findAllocationById = async (id) => {
  return await Allocation.findById(id)
    .populate('skillSet')
    .populate('requestedBy');
};

exports.updateRequestById = async (id, updateData) => {
  const { status, allocatedEmployees, requestedEmployeeNames, updatedEmployeeRole } = updateData;
  return await Allocation.findByIdAndUpdate(
    id,
    {
      $set: { allocatedEmployees, status },
      $push: {
        history: {
          requestedEmployeeNames,
          updatedEmployeeRole,
          status,
          date: new Date()
        }
      }
    },
    { new: true }
  )
    .populate('skillSet')
    .populate('requestedBy');
};

exports.findPendingRequests = async (id) => {
  return await Allocation.find({projectId: id, status: 'Pending' })
    .populate('skillSet', 'name')
    .select('skillSet status numberOfEmployees allocatedEmployees startDate endDate priority');
};
exports.findAllocationsByProjectId = async (projectId) => {
  return await Allocation.find({ projectId: projectId })
    .populate('skillSet', 'name')
    .lean();
};