const cron = require('node-cron');
const Employee = require('../database/models/employeeSchema');
const teamService = require('../modules/Team/Services/team.service');

async function updateProjectStatus(employeeId, projectId) {
  try {
    const updatedEmployee = await teamService.editProjectBenchStatus(employeeId, projectId, 'On bench');

    if (updatedEmployee) {
      console.log(`Updated status to 'On bench' for employee ${employeeId} and project ${projectId}`);
    } else {
      console.log(`No update made for employee ${employeeId} and project ${projectId}`);
    }
  } catch (error) {
    console.error('Error updating project status:', error);
  }
}

async function checkAndUpdateProjectStatuses() {
  try {
    const currentDate = new Date();
    currentDate.setHours(0, 0, 0, 0); // Set to start of day

    console.log(`Checking project end dates for: ${currentDate.toISOString()}`);

    const employees = await Employee.find().populate({
      path: 'Projects.projectId',
      model: 'ProjectTeamMember',
      populate: {
        path: 'project',
        model: 'Project'
      }
    });

    for (const employee of employees) {
      for (const project of employee.Projects) {
        if (project.projectId && project.projectId.project && project.projectId.project.endDate) {
          const endDate = new Date(project.projectId.project.endDate);
          endDate.setHours(0, 0, 0, 0); // Set to start of day for comparison

          if (endDate.getTime() === currentDate.getTime()) {
            console.log(`Project ending today for team member: ${employee.name}`);
            console.log(`Project: ${project.projectId.project.name}`);
            console.log(`End Date: ${endDate.toISOString()}`);

            // Schedule the status update for midnight
            const midnight = new Date(currentDate);
            midnight.setHours(24, 0, 0, 0);
            const delay = midnight.getTime() - Date.now();

            setTimeout(() => {
              updateProjectStatus(employee._id.toString(), project.projectId._id.toString());
            }, delay);

            console.log(`Status update scheduled for midnight: ${midnight.toISOString()}`);
            console.log('---');
          }
        }
      }
    }

    console.log('Daily project status check completed');
  } catch (error) {
    console.error('Error checking project statuses:', error);
  }
}

function resourceOnBenchCrone() {
  // Run every day at midnight (00:00)
  cron.schedule('0 0 * * *', () => {
    console.log('Running daily project status check...');
    checkAndUpdateProjectStatuses();
  });

  console.log('Cron job started. Project statuses will be checked daily at midnight.');
}

module.exports = resourceOnBenchCrone;