const nodemailer = require('nodemailer');

async function sendEmail(email, subject, text) {
  try {
    // Ensure environment variables are set for security
    if (!process.env.FROM || !process.env.PASS || !process.env.SERVICE) {
      throw new Error('Missing required environment variables: USER, PASS, SERVICE');
    }
       
    const transporter = nodemailer.createTransport({
      service: process.env.SERVICE, // Use a secure email service like Gmail, Outlook, etc.
      port: 587, // Standard port for secure SMTP connection
      secure: true, // Enable TLS encryption for secure communication
      auth: {
        user: process.env.FROM,
        pass: process.env.PASS,
      },
    });
    await transporter.sendMail({
      from: process.env.FROM, // Sender email address
      to: email, // Recipient email address
      subject: subject,
      text: text,
    });

    console.log('Email sent successfully!');
  } catch (error) {
    console.error('Error sending email:', error.message);
  }
}

module.exports = sendEmail; // Export the function
